;	======================================
;	        5fach Blinker mit Tiny13
;	======================================

;	--------- Belegung des Ports ---------

;	B0: Output Channel 1
;	B1: Output Channel 2
;	B2: Output Channel 3
;	B3: Output Channel 4
;	B4: Output Channel 5

;	--------- Belegung der Timer ---------

;	Timer0: Interrupt alle 0,0034s (Vorteiler CK/8)

;	 Standard-Definitionen fr ATtiny13
	.include "tn13def.inc"

;	-------- Konstanten festlegen --------

	.equ	cmax	=28		;Zeitschleifendauer (0,0956s)
	.equ	c1max	=14		;Endwert Counter 1
	.equ	c2max	=13		;Endwert Counter 2
	.equ	c3max	=12		;Endwert Counter 3
	.equ	c4max	=11		;Endwert Counter 4
	.equ	c5max	=10		;Endwert Counter 5
	.equ	port	=portb
	.equ	pin	=pinb
	.equ	ddr	=ddrb
	.equ	out1	=0		;Channel 1
	.equ	out2	=1		;Channel 2
	.equ	out3	=2		;Channel 3
	.equ	out4	=3		;Channel 4
	.equ	out5	=4		;Channel 5

;	------- Register-Definitionen --------

	.def	stor	=r0		;storage variable for LPM
	.def	flags	=r1		;storage variable for flags
	.def	temp	=r16		;temporary storage variable 1
	.def	temp2	=r17		;temporary storage variable 2
	.def	c1	=r18		;counter variable 1
	.def	c2	=r19		;counter variable 2
	.def	c3	=r20		;counter variable 3
	.def	c4	=r21		;counter variable 4
	.def	c5	=r22		;counter variable 5
	.def	count	=r23		;waiting time counter

;	- Programmbeginn, Interrupt-Vektoren -

	.cseg
	.org	0x0000

reset:	rjmp	initia			;Programmstart
exint0:	reti
pncnge:	reti
t0ovfl:	rjmp	timer0
eerdy:	reti
ancomp:	reti
t0coma:	reti
t0comb:	reti
wdtto:	reti
adccc:	reti

;	Initialisierung von RAM, I/O und Interrupts

initia:	cli				;Interrupts sperren
	ldi	temp,0x1f
	out	port,temp		;Alles auf High
	out	ddr,temp		;Alles auf Output
	ldi	temp,1<<toie0
	out	timsk0,temp		;Timer0 Interrupt
	ldi	temp,1<<cs01
	out	tccr0b,temp		;Timer0 Overflow
	sei				;Interrupts starten

main:	inc	c1
	cpi	c1,c1max
	brlo	c2a
	clr	c1
	sbis	port,out1
	rjmp	c1an
	cbi	port,out1
	rjmp	c2a
c1an:	sbi	port,out1

c2a:	inc	c2
	cpi	c2,c2max
	brlo	c3a
	clr	c2
	sbis	port,out2
	rjmp	c2an
	cbi	port,out2
	rjmp	c3a
c2an:	sbi	port,out2

c3a:	inc	c3
	cpi	c3,c3max
	brlo	c4a
	clr	c3
	sbis	port,out3
	rjmp	c3an
	cbi	port,out3
	rjmp	c4a
c3an:	sbi	port,out3

c4a:	inc	c4
	cpi	c4,c4max
	brlo	c5a
	clr	c4
	sbis	port,out4
	rjmp	c4an
	cbi	port,out4
	rjmp	c5a
c4an:	sbi	port,out4

c5a:	inc	c5
	cpi	c5,c5max
	brlo	wait
	clr	c5
	sbis	port,out5
	rjmp	c5an
	cbi	port,out5
	rjmp	wait
c5an:	sbi	port,out5

wait:	clr	count
wait2:	cpi	count,cmax
	brlo	wait2
	rjmp	main

timer0:	in	flags,sreg	;Save Flags
	inc	count
	out	sreg,flags	;Restore Flags
	reti